==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/DataChartDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesViewerDescriptionMetadata } from "./SeriesViewerDescriptionMetadata";
import { DataChartDescription } from "./DataChartDescription";
/**
 * @hidden
 */
var DataChartDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataChartDescriptionMetadata, _super);
    function DataChartDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataChartDescriptionMetadata.b = function (a) {
        if (DataChartDescriptionMetadata.a == null) {
            DataChartDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataChartDescriptionMetadata.c(DataChartDescriptionMetadata.a);
        }
        if (a.g(DataChartDescriptionMetadata.a)) {
            return;
        }
        a.s(DataChartDescriptionMetadata.a);
    };
    DataChartDescriptionMetadata.c = function (a) {
        SeriesViewerDescriptionMetadata.c(a);
        a.item("IsSquare", "Boolean");
        a.item("WindowScaleHorizontal", "Number:double");
        a.item("WindowScaleVertical", "Number:double");
        a.item("ActualWindowScaleHorizontal", "Number:double");
        a.item("ActualWindowScaleVertical", "Number:double");
        a.item("IsHorizontalZoomEnabled", "Boolean");
        a.item("IsVerticalZoomEnabled", "Boolean");
        a.item("GridMode", "ExportedType:string:GridMode");
        a.item("GridMode@names", "None;BeforeSeries;BehindSeries");
        a.item("AlignsGridLinesToPixels", "Boolean");
        a.item("AutoExpandMarginMaximumValue", "Number:double");
        a.item("AutoExpandMarginExtraPadding", "Number:double");
        a.item("ShouldSuppressAxisLabelTruncation", "Boolean");
        a.item("ShouldAutoExpandMarginForInitialLabels", "Boolean");
        a.item("ShouldConsiderAutoRotationForInitialLabels", "Boolean");
        a.item("SuppressAutoMarginAndAngleRecalculation", "Boolean");
        a.item("AutoMarginAndAngleUpdateMode", "ExportedType:string:AutoMarginsAndAngleUpdateMode");
        a.item("AutoMarginAndAngleUpdateMode@names", "None;SizeChanging;SizeChangingAndZoom");
        a.item("DefaultAxisStroke", "Brush");
        a.item("DefaultAxisMajorStroke", "Brush");
        a.item("DefaultAxisMinorStroke", "Brush");
        a.item("Axes", "Collection:Axis:AxisCollection:Axis");
        a.item("ActualPlotAreaMarginLeft", "Number:double");
        a.item("ActualPlotAreaMarginTop", "Number:double");
        a.item("ActualPlotAreaMarginRight", "Number:double");
        a.item("ActualPlotAreaMarginBottom", "Number:double");
        a.item("ComputedPlotAreaMarginMode", "ExportedType:string:ComputedPlotAreaMarginMode");
        a.item("ComputedPlotAreaMarginMode@names", "Auto;Series;None");
        a.item("SeriesPlotAreaMarginHorizontalMode", "ExportedType:string:SeriesPlotAreaMarginHorizontalMode");
        a.item("SeriesPlotAreaMarginHorizontalMode@names", "Auto;LeftMarginRightMargin;LeftBufferRightBuffer;LeftMarginRightBuffer;LeftBufferRightMargin;None");
        a.item("SeriesPlotAreaMarginVerticalMode", "ExportedType:string:SeriesPlotAreaMarginVerticalMode");
        a.item("SeriesPlotAreaMarginVerticalMode@names", "Auto;BottomMarginTopMargin;BottomBufferTopBuffer;BottomMarginTopBuffer;BottomBufferTopMargin;None");
        a.item("PlotAreaMarginLeft", "Number:double");
        a.item("PlotAreaMarginTop", "Number:double");
        a.item("PlotAreaMarginRight", "Number:double");
        a.item("PlotAreaMarginBottom", "Number:double");
        DataChartDescriptionMetadata.e(a);
    };
    DataChartDescriptionMetadata.d = function (a) {
        DataChartDescriptionMetadata.b(a);
        a.u("DataChart", function () { return new DataChartDescription(); });
        a.t("DataChart", DataChartDescriptionMetadata.a);
    };
    DataChartDescriptionMetadata.e = function (a) {
        a.item("_qualifiedName", "String:Infragistics.Controls.Charts.XamDataChart");
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
    };
    DataChartDescriptionMetadata.$t = markType(DataChartDescriptionMetadata, 'DataChartDescriptionMetadata');
    DataChartDescriptionMetadata.a = null;
    return DataChartDescriptionMetadata;
}(Base));
export { DataChartDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/DataChartDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesViewerDescriptionMetadata } from "./SeriesViewerDescriptionMetadata";
import { DataChartDescription } from "./DataChartDescription";
/**
 * @hidden
 */
var DataChartDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataChartDescriptionMetadata, _super);
    function DataChartDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataChartDescriptionMetadata.b = function (a) {
        if (DataChartDescriptionMetadata.a == null) {
            DataChartDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataChartDescriptionMetadata.c(DataChartDescriptionMetadata.a);
        }
        if (a.j(DataChartDescriptionMetadata.a)) {
            return;
        }
        a.y(DataChartDescriptionMetadata.a);
    };
    DataChartDescriptionMetadata.c = function (a) {
        SeriesViewerDescriptionMetadata.c(a);
        a.item("IsSquare", "Boolean");
        a.item("WindowScaleHorizontal", "Number:double");
        a.item("WindowScaleVertical", "Number:double");
        a.item("ActualWindowScaleHorizontal", "Number:double");
        a.item("ActualWindowScaleVertical", "Number:double");
        a.item("IsHorizontalZoomEnabled", "Boolean");
        a.item("IsVerticalZoomEnabled", "Boolean");
        a.item("GridMode", "ExportedType:string:GridMode");
        a.item("GridMode@names", "None;BeforeSeries;BehindSeries");
        a.item("AlignsGridLinesToPixels", "Boolean");
        a.item("AutoExpandMarginMaximumValue", "Number:double");
        a.item("AutoExpandMarginExtraPadding", "Number:double");
        a.item("ShouldSuppressAxisLabelTruncation", "Boolean");
        a.item("ShouldAutoExpandMarginForInitialLabels", "Boolean");
        a.item("ShouldConsiderAutoRotationForInitialLabels", "Boolean");
        a.item("SuppressAutoMarginAndAngleRecalculation", "Boolean");
        a.item("AutoMarginAndAngleUpdateMode", "ExportedType:string:AutoMarginsAndAngleUpdateMode");
        a.item("AutoMarginAndAngleUpdateMode@names", "None;SizeChanging;SizeChangingAndZoom");
        a.item("DefaultAxisStroke", "Brush");
        a.item("DefaultAxisMajorStroke", "Brush");
        a.item("DefaultAxisMinorStroke", "Brush");
        a.item("Axes", "Collection:Axis:AxisCollection:Axis");
        a.item("ActualPlotAreaMarginLeft", "Number:double");
        a.item("ActualPlotAreaMarginTop", "Number:double");
        a.item("ActualPlotAreaMarginRight", "Number:double");
        a.item("ActualPlotAreaMarginBottom", "Number:double");
        a.item("ComputedPlotAreaMarginMode", "ExportedType:string:ComputedPlotAreaMarginMode");
        a.item("ComputedPlotAreaMarginMode@names", "Auto;Series;None");
        a.item("SeriesPlotAreaMarginHorizontalMode", "ExportedType:string:SeriesPlotAreaMarginHorizontalMode");
        a.item("SeriesPlotAreaMarginHorizontalMode@names", "Auto;LeftMarginRightMargin;LeftBufferRightBuffer;LeftMarginRightBuffer;LeftBufferRightMargin;None");
        a.item("SeriesPlotAreaMarginVerticalMode", "ExportedType:string:SeriesPlotAreaMarginVerticalMode");
        a.item("SeriesPlotAreaMarginVerticalMode@names", "Auto;BottomMarginTopMargin;BottomBufferTopBuffer;BottomMarginTopBuffer;BottomBufferTopMargin;None");
        a.item("PlotAreaMarginLeft", "Number:double");
        a.item("PlotAreaMarginTop", "Number:double");
        a.item("PlotAreaMarginRight", "Number:double");
        a.item("PlotAreaMarginBottom", "Number:double");
        DataChartDescriptionMetadata.e(a);
    };
    DataChartDescriptionMetadata.d = function (a) {
        DataChartDescriptionMetadata.b(a);
        a.aa("DataChart", function () { return new DataChartDescription(); });
        a.z("DataChart", DataChartDescriptionMetadata.a);
    };
    DataChartDescriptionMetadata.e = function (a) {
        a.item("_qualifiedName", "String:Infragistics.Controls.Charts.XamDataChart");
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
    };
    DataChartDescriptionMetadata.$t = markType(DataChartDescriptionMetadata, 'DataChartDescriptionMetadata');
    DataChartDescriptionMetadata.a = null;
    return DataChartDescriptionMetadata;
}(Base));
export { DataChartDescriptionMetadata };
